package org.springblade.modules.system.controller;

import java.io.File;
import java.io.IOException;
import java.util.UUID;

import org.springblade.core.tool.api.R;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import cn.hutool.core.io.FileUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * 文件上传
 */
@RestController
@Api(value = "附件管理controller", tags = {"附件管理接口"})
@RequestMapping("/file")
public class FileController {

    @Value("${blade.file.uploadPath}")
    private String picDir;

    @PostMapping("/uploadFile")
    @ApiOperation(value = "上传附件", notes = "上传附件，不大于100M")
    public R uploadFile(MultipartFile file) {
        if (null == file) {
            return R.fail("文件不能为空");
        }
        String oFileName = file.getOriginalFilename();
        String fileSuffix = oFileName.substring(oFileName.lastIndexOf("."));

        if (!".jpg".equalsIgnoreCase(fileSuffix) &&
                !".jpeg".equalsIgnoreCase(fileSuffix) &&
                !".gif".equalsIgnoreCase(fileSuffix) &&
                !".png".equalsIgnoreCase(fileSuffix) &&
                !".pdf".equalsIgnoreCase(fileSuffix) &&
                !".doc".equalsIgnoreCase(fileSuffix) &&
                !".docx".equalsIgnoreCase(fileSuffix) &&
                !".xls".equalsIgnoreCase(fileSuffix) &&
                !".xlsx".equalsIgnoreCase(fileSuffix)
        ) {

            return R.fail("只能上传jpg/jpeg/gif/png/pdf/doc/xls类型的文件");
        }

        if (file.getSize() > 1024 * 1000 * 100) {
            return R.fail("附件不得大于100M");
        }

        String tempFileName = UUID.randomUUID().toString() + fileSuffix;

        File f = new File(picDir + tempFileName);
        try {
        	FileUtil.writeFromStream(file.getInputStream(), f);
//            FileUtils.copyInputStreamToFile(file.getInputStream(), f);
        } catch (IOException e) {
            e.printStackTrace();
        }

        return R.success("uploads/" + tempFileName);
    }


}
